@@ -231,7 +231,8 @@ void setup_wm_hints(FvwmWindow *tmp_win)
 
 static void destroy_window_font(FvwmWindow *tmp_win)
 {
-  if (HAS_WINDOW_FONT(tmp_win))
+  if (HAS_WINDOW_FONT(tmp_win) &&
+      tmp_win->title_font.font != Scr.DefaultFont.font)
   {
     FreeFvwmFont(dpy, &(tmp_win->title_font));
   }
@@ -263,13 +264,12 @@ void setup_window_font(
     old_height = tmp_win->title_g.height;
   }
 
+  if (do_destroy)
+  {
+    destroy_window_font(tmp_win);
+  }
   if (has_font)
   {
-    if (do_destroy)
-    {
-      destroy_window_font(tmp_win);
-    }
-
     if (!SGET_WINDOW_FONT(*pstyle))
     {
       has_font = False;
@@ -323,7 +323,8 @@ void setup_window_font(
 
 static void destroy_icon_font(FvwmWindow *tmp_win)
 {
-  if (HAS_ICON_FONT(tmp_win))
+  if (HAS_ICON_FONT(tmp_win) &&
+      tmp_win->icon_font.font != Scr.DefaultFont.font)
   {
     FreeFvwmFont(dpy, &(tmp_win->icon_font));
   }
@@ -345,13 +346,12 @@ void setup_icon_font(
     return;
   }
 
+  if (do_destroy)
+  {
+    destroy_icon_font(tmp_win);
+  }
   if (has_font)
   {
-    if (do_destroy)
-    {
-      destroy_icon_font(tmp_win);
-    }
-
     if (!SGET_ICON_FONT(*pstyle))
     {
       has_font = False;
