@@ -23,7 +23,7 @@ int ParseBinding(
 void key_binding(F_CMD_ARGS);
 void pointerkey_binding(F_CMD_ARGS);
 void mouse_binding(F_CMD_ARGS);
-STROKE_CODE(void stroke_binding(F_CMD_ARGS));
+STROKE_CODE(void stroke_binding(F_CMD_ARGS);)
 unsigned int MaskUsedModifiers(unsigned int in_modifiers);
 unsigned int GetUnusedModifiers(void);
 void ignore_modifiers(F_CMD_ARGS);
