@@ -205,7 +205,12 @@ void HandleFocusIn(void)
     fc = GetColor("White");
     bc = GetColor("Black");
   }
-  else if (Tmp_win != Scr.Hilite)
+  else if (Tmp_win != Scr.Hilite
+	   /* domivogt (16-May-2000): This check is necessary to force sending
+	    * a M_FOCUS_CHANGE packet after an unmanaged window was focused.
+	    * Otherwise fvwm would believe that Scr.Hilite was still focused and
+	    * not send any info to the modules. */
+	   || last_focus_fw == None)
   {
     DrawDecorations(Tmp_win, DRAW_ALL, True, True, None);
     focus_w = Tmp_win->w;
@@ -228,7 +233,8 @@ void HandleFocusIn(void)
   {
     return;
   }
-  if (is_never_focused || focus_w != last_focus_w || focus_fw != last_focus_fw)
+  if (is_never_focused || last_focus_fw == None ||
+      focus_w != last_focus_w || focus_fw != last_focus_fw)
   {
     BroadcastPacket(M_FOCUS_CHANGE, 6, focus_w, focus_fw,
                     (unsigned long)IsLastFocusSetByMouse(), fc, bc);
@@ -1335,8 +1341,7 @@ void HandleButtonPress(void)
 	 Scr.Ungrabbed = Tmp_win;
 	}
 
-    if (((DO_RAISE_TRANSIENT(Tmp_win) && DO_FLIP_TRANSIENT(Tmp_win)) ||
-	 !is_on_top_of_layer(Tmp_win))&&
+    if (!is_on_top_of_layer(Tmp_win) &&
         MaskUsedModifiers(Event.xbutton.state) == 0)
     {
       RaiseWindow(Tmp_win);
@@ -1497,19 +1502,19 @@ void HandleEnterNotify(void)
 
   /* look for a matching leaveNotify which would nullify this enterNotify */
   if(XCheckTypedWindowEvent (dpy, ewp->window, LeaveNotify, &d))
+  {
+    /*
+     * RBW - if we're in startup, this is a coerced focus, so we don't
+     * want to save the event time, or exit prematurely.
+     */
+    if (!fFvwmInStartup)
     {
-      /*
-         RBW - if we're in startup, this is a coerced focus, so we don't
-         want to save the event time, or exit prematurely.
-      */
-      if (! fFvwmInStartup)
-        {
-          StashEventTime(&d);
-          if((d.xcrossing.mode==NotifyNormal)&&
-	     (d.xcrossing.detail!=NotifyInferior))
-	    return;
-        }
+      StashEventTime(&d);
+      if((d.xcrossing.mode==NotifyNormal)&&
+	 (d.xcrossing.detail!=NotifyInferior))
+	return;
     }
+  }
 
   /* an EnterEvent in one of the PanFrameWindows activates the Paging */
   if (ewp->window==Scr.PanFrameTop.win
@@ -1525,7 +1530,6 @@ void HandleEnterNotify(void)
     return;
   }
 
-  /* multi screen? */
   if (ewp->window == Scr.Root)
   {
     if (!Scr.Focus || HAS_MOUSE_FOCUS(Scr.Focus))
@@ -1596,16 +1600,19 @@ void HandleLeaveNotify(void)
   /* CDE-like behaviour of raising the icon title if the icon
      gets the focus (in particular if the cursor is over the icon) */
   if (Tmp_win && IS_ICONIFIED(Tmp_win))
-    {
-      SET_ICON_ENTERED(Tmp_win,0);
-      DrawIconWindow (Tmp_win);
-    }
+  {
+    SET_ICON_ENTERED(Tmp_win,0);
+    DrawIconWindow (Tmp_win);
+  }
 
   /* If we leave the root window, then we're really moving
    * another screen on a multiple screen display, and we
    * need to de-focus and unhighlight to make sure that we
    * don't end up with more than one highlighted window at a time */
-  if(Event.xcrossing.window == Scr.Root)
+  if(Event.xcrossing.window == Scr.Root
+     /* domivogt (16-May-2000): added this test because somehow fvwm sometimes
+      * get a LeaveNotify on the root window although it is single screen. */
+     && Scr.NumberOfScreens > 1)
   {
     if(Event.xcrossing.mode == NotifyNormal)
     {
@@ -2135,8 +2142,23 @@ int My_XNextEvent(Display *dpy, XEvent *event)
 
   DBUG("My_XNextEvent","Routine Entered");
 
+/* include this next bit if HandleModuleInput() gets called anywhere else
+ * with queueing turned on.  Because this routine is the only place that
+ * queuing is on _and_ ExecuteCommandQueue is always called immediately after
+ * it is impossible for there to be anything in the queue at this point */
+#if 0
+  /* execute any commands queued up */
+  DBUG("My_XNextEvent", "executing module comand queue");
+  ExecuteCommandQueue()
+#endif
+
+  /* check for any X events already queued up.
+   * Side effect: this does an XFlush if no events are queued
+   * Make sure nothing between here and the select causes further X
+   * requests to be sent or the select may block even though there
+   * events in the queue */
   if(XPending(dpy)) {
-    DBUG("My_XNextEvent","taking care of queued up events & returning");
+    DBUG("My_XNextEvent","taking care of queued up events & returning (1)");
     XNextEvent(dpy,event);
     StashEventTime(event);
     return 1;
@@ -2156,17 +2178,18 @@ int My_XNextEvent(Display *dpy, XEvent *event)
     if (i == npipes || writePipes[i+1] == 0)
     {
       DBUG("My_XNextEvent", "Starting up after command lines modules\n");
-      StartupStuff();
       timeoutP = NULL; /* set an infinite timeout to stop ticking */
+      StartupStuff(); /* This may cause X requests to be sent */
+      return 0; /* so return without select()ing */
     }
   }
 
   FD_ZERO(&in_fdset);
+  FD_ZERO(&out_fdset);
   FD_SET(x_fd,&in_fdset);
-  /* nothing is done here if fvem was compiled without session support */
+  /* nothing is done here if fvwm was compiled without session support */
   if (sm_fd >= 0)
     FD_SET(sm_fd, &in_fdset);
-  FD_ZERO(&out_fdset);
   for(i=0; i<npipes; i++) {
     if(readPipes[i]>=0)
       FD_SET(readPipes[i], &in_fdset);
@@ -2175,7 +2198,6 @@ int My_XNextEvent(Display *dpy, XEvent *event)
   }
 
   DBUG("My_XNextEvent","waiting for module input/output");
-  XFlush(dpy);
   if (fvwmSelect(fd_width, &in_fdset, &out_fdset, 0, timeoutP) > 0) {
 
     /* Check for module input. */
@@ -2183,19 +2205,24 @@ int My_XNextEvent(Display *dpy, XEvent *event)
       if ((readPipes[i] >= 0) && FD_ISSET(readPipes[i], &in_fdset)) {
         if (read(readPipes[i], &targetWindow, sizeof(Window)) > 0) {
           DBUG("My_XNextEvent","calling HandleModuleInput");
-          HandleModuleInput(targetWindow, i, NULL);
+          /* Add one module message to the queue */
+          HandleModuleInput(targetWindow, i, NULL, True);
 	} else {
           DBUG("My_XNextEvent","calling KillModule");
           KillModule(i);
         }
       }
       if ((writePipes[i] >= 0) && FD_ISSET(writePipes[i], &out_fdset)) {
-        DBUG("My_XNextEvent","calling FlushQueue");
-        FlushQueue(i);
+        DBUG("My_XNextEvent","calling FlushMessageQueue");
+        FlushMessageQueue(i);
       }
     }
 
-    /* nothing is done here if fvem was compiled without session support */
+    /* execute any commands queued up */
+    DBUG("My_XNextEvent", "executing module comand queue");
+    ExecuteCommandQueue();
+
+    /* nothing is done here if fvwm was compiled without session support */
     if ((sm_fd >= 0) && (FD_ISSET(sm_fd, &in_fdset)))
       ProcessICEMsgs();
 
@@ -2212,15 +2239,18 @@ int My_XNextEvent(Display *dpy, XEvent *event)
     }
   }
 
+  /* check for X events again, rather than return 0 and get called again */
+  if(XPending(dpy)) {
+    DBUG("My_XNextEvent","taking care of queued up events & returning (2)");
+    XNextEvent(dpy,event);
+    StashEventTime(event);
+    return 1;
+  }
+
   DBUG("My_XNextEvent","leaving My_XNextEvent");
   return 0;
 }
 
-
-
-
-
-
 /*
 ** Procedure:
 **   InitEventHandlerJumpTable
