@@ -44,6 +44,7 @@
 #include "cursor.h"
 #include "functions.h"
 #include "bindings.h"
+#include "events.h"
 #include "misc.h"
 #include "screen.h"
 #include "defaults.h"
@@ -1101,6 +1102,9 @@ void DeIconify(FvwmWindow *tmp_win)
 	r.y = t->icon_g.y;
 	r.width = t->icon_g.width;
 	r.height = t->icon_p_height+t->icon_g.height;
+	/* update frame geometry in case the icon was moved over a page
+	 * boundary*/
+	update_relative_geometry(t);
 	if (IsRectangleOnThisPage(&r, t->Desk) &&
 	    !IsRectangleOnThisPage(&(t->frame_g), t->Desk))
 	{
