@@ -73,7 +73,8 @@ void executeModule(F_CMD_ARGS);
 int executeModuleDesperate(F_CMD_ARGS);
 void executeModuleSync(F_CMD_ARGS);
 void initModules(void);
-int HandleModuleInput(Window w, int channel, char *expect);
+void ExecuteModuleCommand(Window w, int channel, char *command);
+Bool HandleModuleInput(Window w, int channel, char *expect, Bool queue);
 void KillModule(int channel);
 void ClosePipes(void);
 void BroadcastPacket(unsigned long event_type, unsigned long num_datum, ...);
@@ -94,9 +95,10 @@ void SendName(int channel, unsigned long event_type, unsigned long data1,
 	      unsigned long data2, unsigned long data3, const char *name);
 void SendStrToModule(F_CMD_ARGS);
 void send_list_func(F_CMD_ARGS);
-void FlushOutputQueues(void);
-void FlushQueue(int Module);
-int PositiveWrite(int module, unsigned long *ptr, int size);
+void FlushAllMessageQueues(void);
+void FlushMessageQueue(int Module);
+void ExecuteCommandQueue(void);
+void PositiveWrite(int module, unsigned long *ptr, int size);
 RETSIGTYPE DeadPipe(int nonsense);
 void set_mask_function(F_CMD_ARGS);
 void setSyncMaskFunc(F_CMD_ARGS);
