@@ -495,6 +495,8 @@ static void InteractiveMove(
   if(IS_MAPPED(tmp_win) && DragWidth*DragHeight <
      (Scr.OpaqueSize*Scr.MyDisplayWidth*Scr.MyDisplayHeight)/100)
     do_move_opaque = True;
+  else if (IS_ICONIFIED(tmp_win))
+    do_move_opaque = True;
   else
   {
     Scr.flags.is_wire_frame_displayed = True;
@@ -611,7 +613,7 @@ static void AnimatedMoveAnyWindow(FvwmWindow *tmp_win, Window w, int startX,
       update_absolute_geometry(tmp_win);
       maximize_adjust_offset(tmp_win);
       BroadcastConfig(M_CONFIGURE_WINDOW, tmp_win);
-      FlushOutputQueues();
+      FlushAllMessageQueues();
     }
 
     usleep(cmsDelay * 1000); /* usleep takes microseconds */
@@ -1137,7 +1139,6 @@ Bool moveLoop(FvwmWindow *tmp_win, int XOffset, int YOffset, int Width,
   FvwmWindow tmp_win_copy;
   int dx = Scr.EdgeScrollX ? Scr.EdgeScrollX : Scr.MyDisplayWidth;
   int dy = Scr.EdgeScrollY ? Scr.EdgeScrollY : Scr.MyDisplayHeight;
-  int count;
   int vx = Scr.Vx;
   int vy = Scr.Vy;
   int xl_orig;
@@ -1153,7 +1154,7 @@ Bool moveLoop(FvwmWindow *tmp_win, int XOffset, int YOffset, int Width,
   int orig_icon_x = 0;
   int orig_icon_y = 0;
 
-  if (!IS_MAPPED(tmp_win))
+  if (!IS_MAPPED(tmp_win) && !IS_ICONIFIED(tmp_win))
     do_move_opaque = False;
   bad_window = None;
   if (IS_ICONIFIED(tmp_win))
@@ -1189,7 +1190,8 @@ Bool moveLoop(FvwmWindow *tmp_win, int XOffset, int YOffset, int Width,
   yt_orig = yt;
 
   /* draw initial outline */
-  if ((!do_move_opaque && !Scr.gs.EmulateMWM) || !IS_MAPPED(tmp_win))
+  if (!IS_ICONIFIED(tmp_win) &&
+      ((!do_move_opaque && !Scr.gs.EmulateMWM) || !IS_MAPPED(tmp_win)))
     MoveOutline(xl, yt, Width - 1, Height - 1);
 
   DisplayPosition(tmp_win,xl,yt,True);
@@ -1223,9 +1225,7 @@ Bool moveLoop(FvwmWindow *tmp_win, int XOffset, int YOffset, int Width,
       XEvent new_event;
 
       /*** logic borrowed from icewm ***/
-      count = Scr.MoveSmoothness;
-      /* if count is zero, loop 'infinitely'; this test is not a bug */
-      while (--count != 0 && XPending(dpy) > 0 &&
+      while (XPending(dpy) > 0 &&
 	     XCheckMaskEvent(dpy, ButtonMotionMask | PointerMotionMask |
 			     ButtonPressMask | ButtonRelease | KeyPressMask,
 			     &new_event))
@@ -1470,7 +1470,7 @@ Bool moveLoop(FvwmWindow *tmp_win, int XOffset, int YOffset, int Width,
       }
       /* only do this with opaque moves, (i.e. the server is not grabbed) */
       BroadcastConfig(M_CONFIGURE_WINDOW, &tmp_win_copy);
-      FlushOutputQueues();
+      FlushAllMessageQueues();
     }
   } /* while (!finished) */
 
@@ -1556,17 +1556,6 @@ static void DisplayPosition(FvwmWindow *tmp_win, int x, int y,int Init)
 }
 
 
-void SetMoveSmoothness(F_CMD_ARGS)
-{
-  int val = 0;
-
-  if (GetIntegerArguments(action, NULL, &val, 1) < 1 || val < 0)
-    Scr.MoveSmoothness = DEFAULT_MOVE_SMOOTHNESS;
-  else
-    Scr.MoveSmoothness = val;
-}
-
-
 void SetMoveThreshold(F_CMD_ARGS)
 {
   int val = 0;
@@ -2273,7 +2262,7 @@ void resize_window(F_CMD_ARGS)
 	/* only do this with opaque resizes, (i.e. the server is not grabbed)
 	 */
 	BroadcastConfig(M_CONFIGURE_WINDOW, tmp_win);
-	FlushOutputQueues();
+	FlushAllMessageQueues();
       }
     }
   }
