@@ -591,7 +591,7 @@ Bool PlaceWindow(
   /*  RBW - 11/02/1998  --  I dont. */
   if ((!PPosOverride)&&(!DO_NOT_SHOW_ON_MAP(tmp_win)))
   {
-    changeDesks(tmp_win->Desk);
+    goto_desk(tmp_win->Desk);
   }
 
   /* Don't move viewport if SkipMapping, or if recapturing the window,
@@ -751,7 +751,7 @@ Bool PlaceWindow(
 
           XMapRaised(dpy,Scr.SizeWindow);
 	  if (moveLoop(
-	    tmp_win, 0, 0, DragWidth, DragHeight, &xl, &yt, False, True))
+	    tmp_win, 0, 0, DragWidth, DragHeight, &xl, &yt, False))
 	  {
 	    /* resize too */
 	    rc = True;
