@@ -37,6 +37,9 @@
 
 /* ----------------------------- stack ring code --------------------------- */
 
+static void RaiseOrLowerWindow(
+  FvwmWindow *t, Bool do_lower, Bool allow_recursion, Bool is_new_window);
+
 /* Remove a window from the stack ring */
 void remove_window_from_stack_ring(FvwmWindow *t)
 {
@@ -74,14 +77,7 @@ Bool position_new_window_in_stack_ring(FvwmWindow *t, Bool do_lower)
      * on this. */
     return False;
   /* RaiseWindow/LowerWindow will put the window in its layer */
-  if (do_lower)
-  {
-    LowerWindow(t);
-  }
-  else
-  {
-    RaiseWindow(t);
-  }
+  RaiseOrLowerWindow(t, do_lower, False, True);
   return True;
 }
 
@@ -213,8 +209,8 @@ static void raise_over_unmanaged(FvwmWindow *t)
 }
 
 
-static Bool must_move_transients(FvwmWindow *t, Bool do_lower,
-				 Bool *found_transient)
+static Bool must_move_transients(
+  FvwmWindow *t, Bool do_lower, Bool *found_transient)
 {
   *found_transient = False;
 
@@ -248,7 +244,10 @@ static Bool must_move_transients(FvwmWindow *t, Bool do_lower,
 	*found_transient = True;
 
         /* transients are not allowed below main in the same layer */
-        if ( !scanning_above_window ) return True;
+        if ( !scanning_above_window )
+        {
+          return True;
+        }
       }
       else if ((scanning_above_window && !do_lower) ||
 	       (*found_transient && do_lower))
@@ -265,7 +264,7 @@ static Bool must_move_transients(FvwmWindow *t, Bool do_lower,
 }
 
 static void RaiseOrLowerWindow(
-  FvwmWindow *t, Bool do_lower, Bool allow_recursion)
+  FvwmWindow *t, Bool do_lower, Bool allow_recursion, Bool is_new_window)
 {
   FvwmWindow *s, *r, *t2, *next, tmp_r;
   unsigned int flags;
@@ -275,10 +274,15 @@ static void RaiseOrLowerWindow(
   Bool do_move_transients;
   Bool found_transient;
   Bool no_movement;
-  Bool flip_at_bottom=False;
   int test_layer;
 
-  if (allow_recursion)
+  /* New windows are simply raised/lowered without touching the transientfor
+   * at first.  Then, further down in the code, RaiseOrLowerWindow() is called
+   * again to raise/lower the transientfor if necessary.  We can not do the
+   * recursion stuff for new windows because the must_move_transients() call
+   * needs a properly ordered stack ring - but the new window is still at the
+   * front of the stack ring. */
+  if (allow_recursion && !is_new_window)
   {
     /*
      * This part makes Raise/Lower on a Transient act on its Main and sibling
@@ -301,45 +305,36 @@ static void RaiseOrLowerWindow(
           if ((!do_lower && DO_RAISE_TRANSIENT(t2)) ||
               (do_lower && DO_LOWER_TRANSIENT(t2))  )
           {
-              RaiseOrLowerWindow(t2,do_lower,False);
-              return;
+	    RaiseOrLowerWindow(t2,do_lower,False,False);
+	    return;
           }
         }
       }
     }
   }
 
-  do_move_transients = must_move_transients(t, do_lower, &found_transient);
-
-  /*
-   * This part implements (Dont)FlipTransient style.
-   *
-   * must_move_transients() believes that main should always be below
-   * its transients. Therefore if it finds a transient but does not wish
-   * move it, this means main and its superior transients are already
-   * in the correct position at the top or bottom of the layer - depending
-   * on do_lower.
-   */
-  no_movement = found_transient && !do_move_transients;
-
-  /*
-   * FlipTransient style may flip from this no_movement state
-   * by moving the main above the transients anyway.
-   * The next Raise/Lower naturally moves main back below its transients.
-   */
-  if (no_movement && DO_FLIP_TRANSIENT(t) &&
-      ((do_lower && DO_LOWER_TRANSIENT(t)) ||
-       (!do_lower && DO_RAISE_TRANSIENT(t))))
+  if (is_new_window)
   {
     no_movement = False;
-    if ( do_lower )
-    {
-      flip_at_bottom = True;
-      do_move_transients = True;
-    }
+    do_move_transients = False;
+  }
+  else
+  {
+    do_move_transients = must_move_transients(t, do_lower, &found_transient);
+
+    /*
+     * This part implements (Dont)FlipTransient style.
+     *
+     * must_move_transients() believes that main should always be below
+     * its transients. Therefore if it finds a transient but does not wish
+     * move it, this means main and its superior transients are already
+     * in the correct position at the top or bottom of the layer - depending
+     * on do_lower.
+     */
+    no_movement = found_transient && !do_move_transients;
   }
 
-  if ( ! no_movement )
+  if (!no_movement)
   {
     /* detach t, so it doesn't make trouble in the loops */
     remove_window_from_stack_ring(t);
@@ -378,15 +373,17 @@ static void RaiseOrLowerWindow(
 	    tmp_r.stack_prev = t2;
 	}
       }
-    }
-    if (do_move_transients && tmp_r.stack_next == &tmp_r)
-    {
+      if (tmp_r.stack_next == &tmp_r)
+      {
 	do_move_transients = False;
+      }
     }
 
     test_layer = t->layer;
     if (do_lower)
-	test_layer--;
+    {
+      test_layer--;
+    }
     /* now find the place to reinsert t and friends */
     for (s = Scr.FvwmRoot.stack_next; s != &Scr.FvwmRoot; s = s->stack_next)
     {
@@ -407,17 +404,9 @@ static void RaiseOrLowerWindow(
     }
 
     /*
-    ** Re-insert t - either above transients at the bottom
-    ** when flipping, or else below transients
+    ** Re-insert t - below transients
     */
-    if ( flip_at_bottom )
-    {
-      add_window_to_stack_ring_after(t, r);
-    }
-    else
-    {
-      add_window_to_stack_ring_after(t, s->stack_prev);
-    }
+    add_window_to_stack_ring_after(t, s->stack_prev);
 
     wins = (Window*) safemalloc (count * sizeof (Window));
 
@@ -433,44 +422,54 @@ static void RaiseOrLowerWindow(
       if (IS_ICONIFIED(t2) && !IS_ICON_SUPPRESSED(t2))
       {
 	if(t2->icon_w != None)
-	    wins[i++] = t2->icon_w;
+	  wins[i++] = t2->icon_w;
 	if(t2->icon_pixmap_w != None)
-	    wins[i++] = t2->icon_pixmap_w;
+	  wins[i++] = t2->icon_pixmap_w;
       }
     }
 
-    changes.sibling = s->frame;
-    if (changes.sibling != None)
+    if (is_new_window && IS_TRANSIENT(t) && DO_STACK_TRANSIENT_PARENT(t))
     {
-      changes.stack_mode = Above;
-      flags = CWSibling|CWStackMode;
+      /* now that the new transient is properly positioned in the stack ring,
+       * raise/lower it again so that its parent is raised/lowered too */
+      RaiseOrLowerWindow(t, do_lower, True, False);
+      return;
     }
     else
     {
-      changes.stack_mode = Below;
-      flags = CWStackMode;
+      changes.sibling = s->frame;
+      if (changes.sibling != None)
+      {
+	changes.stack_mode = Above;
+	flags = CWSibling|CWStackMode;
+      }
+      else
+      {
+	changes.stack_mode = Below;
+	flags = CWStackMode;
+      }
+
+      XConfigureWindow (dpy, r->stack_next->frame, flags, &changes);
+      XRestackWindows (dpy, wins, count);
+
+      /* send out (one or more) M_RESTACK packets for windows between r and s */
+      BroadcastRestack (r, s);
+      if (do_move_transients && tmp_r.stack_next != &tmp_r)
+      {
+	/* send out M_RESTACK for all windows, to make sure we don't forget
+	 * anything. */
+	BroadcastRestack (Scr.FvwmRoot.stack_next, Scr.FvwmRoot.stack_prev);
+      }
+
+      free (wins);
     }
-
-    XConfigureWindow (dpy, r->stack_next->frame, flags, &changes);
-    XRestackWindows (dpy, wins, count);
-
-    /* send out (one or more) M_RESTACK packets for windows between r and s */
-    BroadcastRestack (r, s);
-    if (do_move_transients && tmp_r.stack_next != &tmp_r)
-    {
-      /* send out M_RESTACK for all windows, to make sure we don't forget
-       * anything. */
-      BroadcastRestack (Scr.FvwmRoot.stack_next, Scr.FvwmRoot.stack_prev);
-    }
-
-    free (wins);
   }
 
   if (!do_lower)
   {
     /*
         This hack raises the target and all higher FVWM windows over any
-        override_redirect windows that may be above it. This is used to
+style * grabfocusoff        override_redirect windows that may be above it. This is used to
         cope with ill-bahaved applications that insist on using long-lived
         override_redirects.
     */
@@ -512,6 +511,7 @@ static void RaiseOrLowerWindow(
       }
     }
 
+
     /*  This needs to be done after all the raise hacks.  */
     raisePanFrames();
   }
@@ -529,13 +529,13 @@ static void RaiseOrLowerWindow(
 */
 void RaiseWindow(FvwmWindow *t)
 {
-  RaiseOrLowerWindow(t, False, True);
+  RaiseOrLowerWindow(t, False, True, False);
   return;
 }
 
 void LowerWindow(FvwmWindow *t)
 {
-  RaiseOrLowerWindow(t, True, True);
+  RaiseOrLowerWindow(t, True, True, False);
   return;
 }
 
