@@ -1162,13 +1162,6 @@ void ProcessNewStyle(F_CMD_ARGS)
           ptmpstyle->flag_mask.placement_mode |= PLACE_SMART;
           ptmpstyle->change_mask.placement_mode |= PLACE_SMART;
         }
-        else if(StrEquals(token, "DontFlipTransient"))
-        {
-	  found = True;
-	  SFSET_DO_FLIP_TRANSIENT(*ptmpstyle, 0);
-	  SMSET_DO_FLIP_TRANSIENT(*ptmpstyle, 1);
-	  SCSET_DO_FLIP_TRANSIENT(*ptmpstyle, 1);
-        }
         else if(StrEquals(token, "DONTRAISETRANSIENT"))
         {
 	  found = True;
@@ -1260,13 +1253,6 @@ void ProcessNewStyle(F_CMD_ARGS)
 	  SMSET_IS_FIXED(*ptmpstyle, 1);
 	  SCSET_IS_FIXED(*ptmpstyle, 1);
 	}
-        else if(StrEquals(token, "FlipTransient"))
-        {
-	  found = True;
-	  SFSET_DO_FLIP_TRANSIENT(*ptmpstyle, 1);
-	  SMSET_DO_FLIP_TRANSIENT(*ptmpstyle, 1);
-	  SCSET_DO_FLIP_TRANSIENT(*ptmpstyle, 1);
-        }
         break;
 
       case 'g':
@@ -1406,7 +1392,7 @@ void ProcessNewStyle(F_CMD_ARGS)
 	  SCSET_HAS_ICON_FONT(*ptmpstyle, 1);
 
 	}
-	if(StrEquals(token, "IconOverride"))
+	else if(StrEquals(token, "IconOverride"))
 	{
 	  found = True;
 	  ptmpstyle->flags.icon_override = ICON_OVERRIDE;
@@ -2526,6 +2512,13 @@ void check_window_style_change(
    *   handling the 'usestyle' style
    */
 
+   /*
+   * do_window_list_skip
+   */
+  if (SCDO_WINDOW_LIST_SKIP(*ret_style))
+  {
+    flags->do_update_modules_flags = True;
+  }
   /*
    * has_icon
    * icon_override
@@ -2547,6 +2540,7 @@ void check_window_style_change(
     flags->do_update_icon_font = True;
     flags->do_update_icon_title = True;
     flags->do_update_icon = True;
+    flags->do_update_modules_flags = True;
   }
 
 
@@ -2633,7 +2627,7 @@ void check_window_style_change(
 
   /*
    * has_ol_decor
-   */
+0   */
   if (ret_style->change_mask.has_ol_decor)
   {
     /* old decor overrides 'has_no_icon_title'! */
