@@ -109,13 +109,6 @@
 #define SFSET_DO_CIRCULATE_SKIP_SHADED(st,x) ((st).flags.common.s.do_circulate_skip_shaded = !!(x))
 #define SMSET_DO_CIRCULATE_SKIP_SHADED(st,x) ((st).flag_mask.common.s.do_circulate_skip_shaded = !!(x))
 #define SCSET_DO_CIRCULATE_SKIP_SHADED(st,x) ((st).change_mask.common.s.do_circulate_skip_shaded = !!(x))
-#define SDO_FLIP_TRANSIENT(sf) ((sf).common.s.do_flip_transient)
-#define SFDO_FLIP_TRANSIENT(st) ((st).flags.common.s.do_flip_transient)
-#define SMDO_FLIP_TRANSIENT(st) ((st).flag_mask.common.s.do_flip_transient)
-#define SCDO_FLIP_TRANSIENT(st) ((st).change_mask.common.s.do_flip_transient)
-#define SFSET_DO_FLIP_TRANSIENT(st,x) ((st).flags.common.s.do_flip_transient = !!(x))
-#define SMSET_DO_FLIP_TRANSIENT(st,x) ((st).flag_mask.common.s.do_flip_transient = !!(x))
-#define SCSET_DO_FLIP_TRANSIENT(st,x) ((st).change_mask.common.s.do_flip_transient = !!(x))
 #define SDO_GRAB_FOCUS_WHEN_CREATED(sf) ((sf).common.s.do_grab_focus_when_created)
 #define SFDO_GRAB_FOCUS_WHEN_CREATED(st) ((st).flags.common.s.do_grab_focus_when_created)
 #define SMDO_GRAB_FOCUS_WHEN_CREATED(st) ((st).flag_mask.common.s.do_grab_focus_when_created)
