@@ -25,8 +25,8 @@ void checkPanFrames(void);
 void raisePanFrames(void);
 void initPanFrames(void);
 void MoveViewport(int newx, int newy,Bool);
-void changeDesks_func(F_CMD_ARGS);
-void changeDesks(int desk);
+void goto_desk_func(F_CMD_ARGS);
+void goto_desk(int desk);
 void do_move_window_to_desk(FvwmWindow *tmp_win, int desk);
 void move_window_to_desk(F_CMD_ARGS);
 void scroll(F_CMD_ARGS);
