@@ -1,4 +1,4 @@
-/* $Id: FvwmCommand.c,v 1.13 2000/05/03 20:16:04 mikehan Exp $
+/* $Id: FvwmCommand.c,v 1.14 2000/05/25 10:17:56 domivogt Exp $
  * $Source: /home/cvs/fvwm/fvwm/modules/FvwmCommand/FvwmCommand.c,v $
  *
  * Fvwm command input interface.
@@ -702,8 +702,6 @@ void list_configure(unsigned long *body)
 	    DO_SKIP_ICON_CIRCULATE( cfgpacket ) );
     printf( "do_circulate_skip_shaded: %d\n",
 	    DO_SKIP_SHADED_CIRCULATE( cfgpacket ) );
-    printf( "do_flip_transient: %d\n",
-	    DO_FLIP_TRANSIENT( cfgpacket ) );
     printf( "do_grab_focus_when_created: %d\n",
 	    DO_GRAB_FOCUS( cfgpacket ) );
     printf( "do_grab_focus_when_transient_created: %d\n",
