@@ -480,7 +480,8 @@ static char *FuncStrCopy(int *NbArg, long *TabArg)
 static char *LaunchScript (int *NbArg,long *TabArg)
 {
  char *arg,*execstr,*str,*scriptarg,*scriptname;
- int leng,i;
+ unsigned long leng;
+ int i;
  Atom MyAtom;
 
  /* Lecture des arguments */
@@ -526,10 +527,10 @@ static char *LaunchScript (int *NbArg,long *TabArg)
  /* Envoi de la commande */
  write(fd[0], &ref, sizeof(Window));
  leng = strlen(execstr);
- write(fd[0], &leng, sizeof(int));
+ write(fd[0], &leng, sizeof(unsigned long));
  write(fd[0], execstr, leng);
  leng = 1;
- write(fd[0], &leng, sizeof(int));
+ write(fd[0], &leng, sizeof(unsigned long));
  free(execstr);
 
  /* Retourne l'id du fils */
@@ -625,8 +626,11 @@ static char *ReceivFromScript (int *NbArg,long *TabArg)
 
  /* Recuperation du message */
  XConvertSelection(dpy,ASend,AReceiv,propriete,x11base->win,CurrentTime);
- while ((!XCheckTypedEvent(dpy,SelectionNotify,&event))&&(NbEssai<25000))
+ while ((!XCheckTypedEvent(dpy,SelectionNotify,&event))&&(NbEssai<10))
+ {
+  usleep(1);
   NbEssai++;
+ }
  if (event.xselection.property!=None)
   if (event.xselection.selection==ASend)
   {
@@ -641,7 +645,6 @@ static char *ReceivFromScript (int *NbArg,long *TabArg)
     XFree(donnees);
    }
   }
-
  return msg;
 }
 
@@ -652,7 +655,7 @@ static char *ReceivFromScript (int *NbArg,long *TabArg)
 
 static void Exec (int NbArg,long *TabArg)
 {
- int leng = 0;
+ unsigned long leng = 0;
  char *execstr;
  char *tempstr;
  int i;
@@ -660,12 +663,13 @@ static void Exec (int NbArg,long *TabArg)
  for (i=0;i<NbArg;i++)
    leng += strlen(CalcArg(TabArg,&i));
 
- if (leng >= 998) 
+ if (leng >= 998)
  {
-   fprintf(stderr,"[FvwmScript]: too long command %i chars max 998\n", leng);
+   fprintf(stderr, "[FvwmScript]: too long command %i chars max 998\n",
+	   (int)leng);
    return;
  }
-   
+
  execstr=(char*)calloc(1,leng+1);
  for (i=0;i<NbArg;i++)
  {
@@ -676,10 +680,10 @@ static void Exec (int NbArg,long *TabArg)
 
  write(fd[0], &ref, sizeof(Window));
  leng = strlen(execstr);
- write(fd[0], &leng, sizeof(int));
+ write(fd[0], &leng, sizeof(unsigned long));
  write(fd[0], execstr, leng);
  leng = 1;
- write(fd[0], &leng, sizeof(int));
+ write(fd[0], &leng, sizeof(unsigned long));
  free(execstr);
 }
 
