@@ -54,7 +54,7 @@ typedef struct
 /* Function Prototypes */
 extern Button *ButtonNew(char *title, Picture *p, int up);
 extern void InitArray(ButtonArray *array,int x,int y,int w,int h,int rw);
-extern void UpdateArray(ButtonArray *array,int x,int y,int w, int h);
+extern void UpdateArray(ButtonArray *array,int w);
 extern int AddButton(ButtonArray *array, char *title, Picture *p,int up);
 extern int UpdateButton(ButtonArray *array, int butnum, char *title, int up);
 extern void UpdateButtonIconified(
@@ -68,8 +68,9 @@ extern void RemoveButton(ButtonArray *array, int butnum);
 extern Button *find_n(ButtonArray *array, int n);
 extern void FreeButton(Button *ptr);
 extern void FreeAllButtons(ButtonArray *array);
-extern void DoButton(Button *ptr, int x, int y, int w, int h);
-extern void DrawButtonArray(ButtonArray *array, Bool all);
+extern void DoButton(Button *ptr, int x, int y, int w, int h, Bool clear_bg);
+extern void DrawButtonArray(ButtonArray *array, Bool all, Bool clear_bg);
+extern void ExposeAllButtons(ButtonArray *array, XEvent *eventp);
 extern void SwitchButton(ButtonArray *array,int butnum);
 extern int WhichButton(ButtonArray *array,int x, int y);
 extern char *ButtonName(ButtonArray *array, int butnum);
